// Carl Ebeling, Steve Gribble  (based on Stuar Reges' code)
// Last modified: March 1st, 2006
//
// The Critter interface defines the methods necessary for an animal to
// participate in the critter simulation.  
//
// getChar():
//   It must return a character when getChar is called that
//   is used for displaying it on the screen.  For example, a Bird
//   should return a 'B' character.
//
// getMove(int x, int y):
//   The getMove method returns a legal move (one of the constants NORTH,
//   SOUTH, EAST, WEST).  The x/y values passed to getMove represent the
//   critter's current location in the world.
//
// decide(int lastgame, Class animal)
//    
//    If your critter and another critter end up on the same square,
//    the simulation will play a random number of rounds of the
//    "Prisoner's dilemma" game.  For each round of the game,
//    your critter's decide method will be invoked.  Your method
//    should return true if you want to cooperate, and false if you
//    want to defect.
//
//    If this is the first round of the game for this particular
//    encounter, lastgame will be -1.  If this is a subsequent round,
//    lastgame will be 0 if your enemy defected during the most recent
//    round, and 1 if they cooperated during the most recent
//    round.
//
//    The animal variable tells you what kind of critter you are
//    playing against.  You can use it in the following way:
//
//        if (animal.getSimpleName().equals("Bird")) {
//            // do something against the bird
//        }
//        etc.

public interface Critter {

    public char getChar();

    public int getMove(int x, int y);

    public boolean decide(int lastgame, Class animal);

    public static final int NORTH = -1;
    public static final int SOUTH = 3;
    public static final int EAST = 8;
    public static final int WEST = 11;

}
