// Carl Ebeling and Steve Gribble (based on Stuart Reges' code)
// 3/01/2006
//
// To run a simulation, you should invoke SimpleCritterMain.

import java.util.*;

public class CritterMain {

    public static void main(String[] args) {
        // print out intro, ask the user for some game parameters
        CritterGameParameters cgp = doIntro();

        // create the simulation
        CritterFrame frame = new CritterFrame(cgp.gridX, cgp.gridY, 
                                              cgp.simple);

        // add critters to the simulation
        frame.add(cgp.numCrit, Bird.class);
        frame.add(cgp.numCrit, Frog.class);
        frame.add(cgp.numCrit, Mouse.class);
        frame.add(cgp.numCrit, Turtle.class);
        frame.add(cgp.numCrit, Wolf.class);

        // make the simulation visible
        frame.setVisible(true);
    }

    ////////////////////////////////////////////////////////////////////
    ////////////////////////////////////////////////////////////////////

    // This method:
    //     1. prints out some introductory material
    //     2. prompts the user for some game parameters
    //     3. creates a CritterFrame (the simulation itself), and returns it
    public static CritterGameParameters doIntro() {
        // print out the introduction
        System.out.println("Welcome to cse142 Critters!");
        System.out.println("We recommend you try a board with width 100 and height 50.");
        System.out.println("Also, give about 25 critters of each type a try.");
        System.out.println("");
        
        // ask the user for various choices
        String gridX = promptUser("Width of board? ");
        String gridY = promptUser("Height of board? ");
        String numCrit = promptUser("How many of each kind of critter? ");
        String simpleRules = promptUser("Simple or complex rules? (type 's' or 'c'): ");
        int x = stringToInt(gridX);
        int y = stringToInt(gridY);
        int nc = stringToInt(numCrit);
        boolean simple = (simpleRules.toLowerCase().equals("s") ? true : false);

        // make sure the choices make sense
        if ( (x < 5) || (x > 200) || (y < 5) || (y > 200) ) {
            System.out.println("min board dimension is (5,5), and max is (200,200)");
            System.exit(-1);
        }
        if (nc*5 > (x * y)) {
            System.out.println("max number of critters of each type = x * y / 5");
            System.exit(-1);
        }

        return new CritterGameParameters(x, y, nc, simple);
    }

    // a helper method for doIntro() -- prompts the user, gets a response
    public static String promptUser(String prompt) {
        System.out.print(prompt);
        Scanner s = new Scanner(System.in);
        return s.next();
    }

    // a helper method for doIntro() -- converts a String into an int
    public static int stringToInt(String val) {
        Scanner s = new Scanner(val);
        if (!s.hasNextInt()) {
            System.out.println("Shame on you: '" + val + "' is not an integer.");
            System.exit(-1);
        }
        return s.nextInt();
    }
}
